function [obj,varargout] = IsaacIMG(varargin)
% @IsaacIMG : constructeur
%
% (Appeler en TRY-CATCH pour sortie en erreur d'execution)
%
%	obj = IsaacIMG(img,imgname,objROI,objECOL)
%		=> objet @IsaacIMG initialis
%
%	obj = IsaacIMG(img,imgname,nbbused,objROI,objECOL)
%		=> objet @IsaacIMG initialis avec prcision du nb de bits utiliss
%
%	[obj,ok] = IsaacIMG(filename)
%		=> objet @IsaacIMG lu dans un fichier
%
%	obj = IsaacIMG(dirname)
%		=> objet @IsaacIMG cr par concatnation des images d'un dossier
%			avec conversion des images lues en fonction des caractristiques de la 1re image 
%
%	obj = IsaacIMG()
%		=> objet @IsaacIMG par dfaut
%			(non utilis mais obligatoire pour load si aucun objet cr prcdement)
%
%	- img       : matrice image
%	- imgname	: nom de l'image (si '' alors obj.imgname = 'SansNom')
%	- nbbused	: nombre de bits utiliss (1  16/32/64 dans les limites de bitclass)
%	- objROI    : objet @IsaacROI  ou [] si non dfinie
%	- objECOL	: objet @IsaacECOL ou [] si non dfini
%	- ok        : true si obj.img identique au contenu du fichier (sans conversion)
%	- filename	: nom du fichier dans rpertoire courant ou nom complet
%	- dirname	: nom du dossier dans rpertoire courant ou nom complet
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
% Contributor: Clment Bourgeais (2018)
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% DONNES IMAGE
%
%	imgname        : nom de l'image
%	img            : matrice image
%	dimx           : largeur image
%	dimy        	: hauteur image
%	dimz           : nombre de plans de l'image
%	bitclass       : 1/8/16/32/64 bits
%	nbb            : nombre de bits par pixel et par plan (1  16/32/64) <= bitclass
%	min            : min image (matrice 1xdimz)
%	max            : max image (matrice 1xdimz)
%	valmax         : valeur maximum de l'image = 2^nbb -1 si bitclass <32 ou 1 sinon
%
% RGION D'INTRET
%
%	isroi          : false si roi non dfinie
%	roi            : objet @IsaacROI (initialis ou par dfaut)
%	roispamask     : masque (logical) de roi spatiale ou [] si ISAACPREF.OptimiseImgMem
%	roivalmask     : masque (logical) de roi valeur ou [] si ISAACPREF.OptimiseImgMem
%
% DONNES COLORIMTRIQUES
%
%	iscolorspace	: false si colorspace non dfini
%	colorspace		: objet @IsaacECOL (initialis ou par dfaut)
%
% DONNES DE GESTION
%
%	converted		: true si objet de version diffrente convertit, false sinon 
%	version			: version de l'objet 

%---------------------------------------------------------------------------------------------------

objversion = 2;

%---------------------------------------------------------------------------------------------------

global ISAACCONST
global ISAACPREF

switch nargin
case {4,5}
	% Objet initialis
	obj = struct;
	obj = IsaacObjIMGInit(obj,varargin{1});
	obj.imgname = char(varargin{2});
	if isempty(obj.imgname)
		obj.imgname = 'SansNom';
	end	
	if (nargin == 4)
		roi = varargin{3};
		ecol = varargin{4};
	else
		nbb = varargin{3};
		if IsaacBitCheck(obj.img,nbb)
			obj.nbb = nbb;
			obj.valmax = IsaacValMax(obj.nbb);
		else
			error('nombre de bits incompatible avec l''image')
		end
		roi = varargin{4};
		ecol = varargin{5};
	end
	if isempty(roi)
		obj.roi = IsaacROI(obj.dimx,obj.dimy,obj.dimz,obj.nbb); % roi inactive par dfaut
		obj.isroi = false;
	elseif isa(roi,'IsaacROI')
		if ~IsaacROI_check(roi,obj.dimx,obj.dimy,obj.dimz,obj.nbb)
			IsaacMessageWarning('rgion d''intrt ajuste  l''image')
			roi = IsaacROI_adjust(roi,'RoiSpaVal',obj.dimx,obj.dimy,obj.dimz,obj.nbb);
		end
		obj.roi = roi;
		obj.isroi = true;
	else
		error('argument incorrect')
	end	
	InitRoiMask
	if isempty(ecol)
		obj.colorspace = IsaacECOL(); % espace indtermin par dfaut
		obj.iscolorspace = false;
	elseif isa(ecol,'IsaacECOL')
		if ~IsaacECOL_check(ecol,obj.dimz,obj.bitclass)
			error('espace colorimtrique et image incompatibles')
		end	
		obj.colorspace = ecol;
		obj.iscolorspace = true;
	else
		error('argument incorrect')
	end
	obj.converted = false;
	obj.version = objversion;
	obj = class(orderfields(obj),'IsaacIMG'); % orderfields car class est sensible  l'ordre
case 1   
	if verLessThan('matlab', '9.3') 
      % code pour MATLAB 2017a et antrieur
      test_rep = isdir(varargin{1});                                                               %#ok
   else
      % code pour MATLAB 2017b (9.3) et postrieur  
      test_rep = isfolder(varargin{1});
	end  
	if (test_rep)
		% Concatnation des plans d'un dossier
		dd = IsaacDir(varargin{1},'f',true,false);
		j = length(dd);
		ok2 = false;
		if (j)
			% lecture d'une 1ere image valide
			i = 1;
			while (i <= j)
				try
					obj = IsaacIMG(dd{i});
					ok2 = true;
					break
				catch
					IsaacMessageBavard(dd{i},'n''est pas une image valide')
				end
				i = i+1;
			end
			for i = i+1:j
				% lecture des images suivantes
				try
					obj2 = IsaacIMG(dd{i});
				catch
					IsaacMessageBavard(dd{i},'n''est pas une image valide')
					continue
				end
				% concatnation
				obj = IsaacIMG_concat(obj,obj2);
			end
		end
		if ~ok2
         if verLessThan('matlab', '9.1') 
            % code pour MATLAB 2016a et antrieur
            error(['le dossier ',varargin{1},char(10),'ne contient aucune image valide'])       %#ok
         else
            % code pour MATLAB 2016b (9.1) et postrieur  
            error(['le dossier ',varargin{1},newline,'ne contient aucune image valide'])
         end
		else
			[~,obj.imgname] = fileparts(varargin{1});
		end	
	else
		% Lecture dans un fichier
		[~,filename,ext] = fileparts(varargin{1}); 
		if strcmp(ext,ISAACCONST.ExtImg)
			try
				warning off
				var = load('-mat',varargin{1},'IMG'); % variable IMG dans le fichier
				%
				% IMPORTANT : le contrle de version par loadobj s'applique AUTOMATIQUEMENT aux
				%			  objets inclus ROI et ECOL
				%
				warning on
				obj = var.IMG;
				if ~isa(obj,'IsaacIMG')
					% erreur affiche par loadobj
					error('pour provoquer le catch')
				end
			catch
				error('fichier invalide')
			end
			if (obj.dimz > ISAACPREF.ImMaxPlans)
				error('le nombre de plans dpasse la limite fixe en prfrences')
			end
			if (nargout > 1)
				varargout{1} = ~obj.converted;
			end
			% le nom du fichier prvaut sur celui de l'objet lu (le fichier a pu tre renomm)
			obj.imgname = filename;
		else
			obj.imgname = filename;
			if strcmp(ext,'.tif')
				info = imfinfo(varargin{1});
				if isstruct(info) && length(info) > 1 % image multicomposantes en tif
					for i = 1:length(info)
						[img(:,:,i),map] = imread(varargin{1},i);													%#ok
					end
				else
					[img,map] = imread(varargin{1});
				end	
			else
				[img,map] = imread(varargin{1});
			end
			if ~isempty(map)
				% conversion en rgb
				IsaacMessageWarning(['image indexe ',obj.imgname,' convertie en RGB'])
				if (nargout > 1)
					varargout{1} = false;
				end
				obj = IsaacObjIMGInit(obj,im2uint8(ind2rgb(img,map)));
			else
				if (nargout > 1)
					varargout{1} = true;
				end
				obj = IsaacObjIMGInit(obj,img);
			end
			obj.roi = IsaacROI(obj.dimx,obj.dimy,obj.dimz,obj.nbb); % roi inactive par dfaut
			obj.isroi = false;
			InitRoiMask
			obj.colorspace = IsaacECOL(); % espace indtermin par dfaut
			obj.iscolorspace = false;
			obj.converted = false;
			obj.version = objversion;
			obj = class(orderfields(obj),'IsaacIMG'); % orderfields car class est sensible  l'ordre
		end
	end
case 0
	% Objet par dfaut non utilis mais obligatoire
	obj = struct('imgname',{},'img',{},'dimx',{},'dimy',{},'dimz',{},'bitclass',{},'nbb',{}, ...
		'valmax',{},'min',{},'max',{},'isroi',{},'roi',{},'roispamask',{},'roivalmask',{}, ...
		'iscolorspace',{},'colorspace',{},'converted',{},'version',{});
	obj = class(orderfields(obj),'IsaacIMG'); % orderfields car class est sensible  l'ordre
otherwise
	error('nombre d''arguments incorrect')
end

% --- Nested fonction ------------------------------------------------------------------------------

function InitRoiMask
% Initialisation des masques de roi

if ISAACPREF.OptimiseImgMem
	obj.roispamask	= [];
	obj.roivalmask	= [];
elseif obj.isroi
	obj.roispamask = IsaacROI_spamask(obj.roi);
	obj.roivalmask = IsaacROI_valmask(obj.roi,obj.img);
else
	obj.roispamask	= false(obj.dimy,obj.dimx);
	obj.roivalmask	= false(obj.dimy,obj.dimx);
end

end % fin nested fonction

%---------------------------------------------------------------------------------------------------

end % fin IsaacIMG en raison des nested fonctions
