classdef IsaacImage < handle
% @IsaacImage : Handle Class
%
% (Appeler le constructeur en TRY-CATCH pour sortie en erreur d'execution)
%
%	obj = IsaacImage(auteur,objIMG)
%		=> Affiche objIMG comme une nouvelle image
%
%	obj = IsaacImage(auteur,img,name,objROI,objECOL)
%		=> Affiche img comme une nouvelle image de nom name
%
%	obj = IsaacImage(auteur,img,nbbits,name,objROI,objECOL)
%		=> Affiche img comme une nouvelle image de nom name 
%			et prcision du nb de bits utiliss
%
%	obj = IsaacImage(auteur,filename)
%		=> Affiche une nouvelle image  partir d'1 fichier
%
%	obj = IsaacImage(auteur,obj)
%		=> Restauration d'une image ouverte  partir de son fichier
%			(rinitialise tous les paramtres)
% 
%	- auteur    : handle figure outil appelant
%	- objIMG    : objet @IsaacIMG
%	- img       : matrice image
%	- name		: nom de l'image ou ''
%	- nbbits    : nombre de bits de img (1  16/32/64 dans les limites de la classe)
%	- filename	: nom complet du fichier
%	- objROI    : objet @IsaacROI ou [] si non dfinie
%	- objECOL	: objet @IsaacECOL ou [] si non dfini
%
% @-> EVENEMENTS 2/20/31/32
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

properties (Access = private)
% DONNES DE GESTION
status		% -1=  sauver(issue de TempDir ou sans fichier), 0=  sauver(modifie), 1 sinon
filename    % nom complet du fichier d'origine ou '' si sans fichier
% DONNES RELLES
img			% objet @IsaacIMG
% PARAMETRES D'AFFICHAGE
plan        % plans affichs [pi,pj,pk] avec 1 <= p <= nb plans image
marginal    % true si affichage marginal
ED          % true si expansion dynamique
gammaA		% 0.1 ... 1 ... 10
pal			% Indice ISAACCONST.PalStr de la palette associe  un plan affich en marginal
showRoiSpa	% 0|1|2 : rien, roi spatiale, complment (non roi)
            %		-> Rs ou Cs en couleur1
showRoiVal	% 0|1|2 : rien, roi valeurs, complment (non roi)
            %		-> Rv ou Cv en couleur2
            %		-> couleur3 pour intersection (Rs|Cs) et (Rv|Cv)
showRoiComp	% false || true : couleur4 pour ce qui n'est pas marqu
% DONNES GRAPHIQUES
fighnd		% handle de la figure
echelle		% 1/n ... 1 ... n dans les limites de l'cran
zoom        % false || true selon que zoom activ ou non
axImg       % Handle axes
%CData (figure) contenu affich en 3 plans Uint8
end

methods (Access = public)
function obj = IsaacImage(auteur,varargin)
% @IsaacImage : constructeur

global ISAACPRIV
global ISAACCONST
global ISAACPREF

switch nargin
case 2
	if ischar(varargin{1})
		% nouvelle image  partir d'un fichier
		[parentdir,~,ext] = fileparts(varargin{1});
		if isempty(parentdir)
			error('nom de fichier incomplet')
		end
		[obj.img,ok] = IsaacIMG(varargin{1});
		if isempty(ext)
			% le fichier d'origine ne possde pas d'extension
			IsaacMessageWarning(['fichier ',varargin{1}],'Extension absente')
			ok = false;
		end	
		if ~ok || strcmp(parentdir,ISAACCONST.TempDir)
			obj.status = -1;
			obj.filename = '';
			action = 1; % nouvelle image sans fichier
		else
			obj.status = 1;
			obj.filename = varargin{1};
			action = 2; % nouvelle image avec fichier
		end	
	elseif isa(varargin{1},'IsaacImage')
		% restauration image
		obj = varargin{1};
		if obj.status == -1
			error(['l''image ',IsaacIMG_get(obj.img,'ImgName'), ...
				' ne possde pas de fichier'])
		end
		obj.img = IsaacIMG(obj.filename);
		obj.status = 1;
		action = 3; % rinitialisation image
	elseif isa(varargin{1},'IsaacIMG')
		% nouvelle image  partir d'un objet @IsaacIMG
		obj.img = varargin{1};
		obj.status = -1;
		obj.filename = '';
		action = 1; % nouvelle image sans fichier
	else
		error('argument incorrect')
	end	
case 5
	obj.img = IsaacIMG(varargin{1},varargin{2},varargin{3},varargin{4});
	obj.status = -1;
	obj.filename = '';
	action = 1; % nouvelle image sans fichier
case 6
	obj.img = IsaacIMG(varargin{1},varargin{2},varargin{3},varargin{4},varargin{5});
	obj.status = -1;
	obj.filename = '';
	action = 1; % nouvelle image sans fichier
otherwise
	error('nombre d''arguments incorrect')
end

DimX = IsaacIMG_get(obj.img,'DimX');
DimY = IsaacIMG_get(obj.img,'DimY');

% PARAMTRES D'AFFICHAGE
if (IsaacIMG_get(obj.img,'DimZ') == 3)
	obj.plan = [1,2,3];
	obj.marginal = false;
else
	obj.plan = [1,1,1];
	obj.marginal = true;
end
obj.ED = false;
obj.gammaA = 1;
obj.pal = 1;
obj.showRoiSpa = 0;
obj.showRoiVal = 0;
obj.showRoiComp = false;

% DONNES GRAPHIQUES

obj.echelle = IsaacImgScale(1,DimX,DimY);
% chelle 1 souhaite, l'echelle effective peut tre diffrente
obj.zoom = false;

%---------------------------------------------------------------------------------------------------

% figure(position selon ISAACCONST.DefPos) + ISAACCONST.EpButCible pour la place du bouton select
if (action == 3 ) % rinitialisation image
	figure(obj.fighnd)
	clf('reset')
else
	obj.fighnd = figure;
end
set(obj.fighnd, ...
	'CloseRequestFcn',{@IsaacImage_cb,obj.fighnd,'CloseBox'}, ...
	'Position',IsaacFenPos(ISAACCONST.DefPos(1),ISAACCONST.DefPos(2), ...
		round(DimX * obj.echelle),round(DimY * obj.echelle) + ISAACCONST.EpButCible,0), ...
	'WindowButtonUpFcn',{@IsaacImage_cb,obj.fighnd,'ButDown'});
figpos = get(obj.fighnd,'Position');
HauteurImage = figpos(4)-ISAACCONST.EpButCible;
LargeurImage = figpos(3);
IsaacDefaultProperties(obj.fighnd)
% Axes et image
obj.axImg = axes('Parent',obj.fighnd, ...
	'Box','off', ...
	'DataAspectRatio',[1 1 1], ...
	'DataAspectRatioMode','manual', ...
	'PlotBoxAspectRatio',[1 1 1], ...
	'PlotBoxAspectRatioMode','manual', ...
	'Position',[0  0 LargeurImage HauteurImage], ...
	'ActivePositionProperty','Position', ...
	'Visible','off', ...
	'XLim',[1 DimX], ...
	'YLim',[1 DimY], ...
	'XTick',[], ...
	'YTick',[], ...
	'YDir', 'reverse');
h2 = image('Parent',obj.axImg, ...
	'CDataMapping','direct', ...
	'Clipping','on', ...
	'Visible','off', ...
	'CData',[], ...
	'XData',[1, DimX], ...
	'YData',[1, DimY]);
% bouton Select
h1 = uicontrol('Parent',obj.fighnd, ...
	'Callback',{@IsaacImage_cb,obj.fighnd,'ButSelect'}, ...
	'Position',[0 HauteurImage LargeurImage ISAACCONST.EpButCible], ...
	'String',' ', ...
	'Style','pushbutton', ...
	'Tag','ButSelect');

%---------------------------------------------------------------------------------------------------

% Initialisation
% maj ISAACPRIV.TabIsaacImage
if (action ~= 3) % nouvelle image avec ou sans fichier
	ISAACPRIV.NbOpenImg = ISAACPRIV.NbOpenImg+1;
	ISAACPRIV.TabIsaacImage(ISAACPRIV.NbOpenImg) = obj;
	% si l'image cre est la 1re, elle devient la cible
	if (ISAACPRIV.NbOpenImg == 1)
		ISAACPRIV.Cible = obj;
	end	
end
% affichage
set(obj.fighnd,'Name',IsaacImage_title(obj));
IsaacImage_draw(obj)
if (action == 3) % rinitialisation image
	if (obj == ISAACPRIV.Cible)
		% maj marque image si cible
		set(h1,'BackgroundColor',ISAACPREF.CibleColor1)
		% EVENEMENT
		IsaacImage_event(obj,auteur,31)
	else
		% EVENEMENT
		IsaacImage_event(obj,auteur,32)
	end	
else % nouvelle image avec ou sans fichier
	% EVENEMENT
	IsaacImage_event(obj,auteur,20)
	if (obj == ISAACPRIV.Cible)
		% maj marque image
		if (action == 1)
			% nouvelle image sans fichier
			set(h1,'BackgroundColor',ISAACPREF.CibleColor2)
		else
			% nouvelle image avec fichier
			set(h1,'BackgroundColor',ISAACPREF.CibleColor1)
		end
		% EVENEMENT
		IsaacImage_event(obj,auteur,2)
	end
end	
set(h2,'Visible','on')
end % function obj = IsaacImage

% autres mthodes publiques en fichier spars
IsaacImage_cible(obj,auteur)
IsaacImage_finfo(obj)
val = IsaacImage_get(obj,propname)
liste = IsaacImage_mousepix(obj)
rect = IsaacImage_mouserect(obj)
IsaacImage_save(obj,auteur)
IsaacImage_saveas(obj,auteur,filename)
IsaacImage_set(obj,auteur,varargin)

end % methods (Access = public)

methods (Access = private)
% mthodes prives en fichier spars
IsaacImage_draw(obj)
IsaacImage_event(obj,auteur,event)
s = IsaacImage_title(obj)
end

methods (Static)
% autres mthodes en fichier spars
scale = IsaacImgScale(scale,dimx,dimy)
end

end %classdef
	
%---------------------------------------------------------------------------------------------------

function IsaacImage_cb(hsrc,eventdata,fighnd,choix)															%#ok
% Callbacks IsaacImage
%
% IMPORTANT : Si IsaacImage_cb en fichier indpendant obj devrait tre pass en paramtre pour 
%		faire une mthode objet et la valeur de obj serait celle "in scope"  la cration 
%		des handles de callback et non celle contenue dans le tableau ISAACPRIV.TabIsaacImage
%
% @-> EVENEMENTS 1/2/11/12
%
% Isaac Macintosh - Alain Clment 160211

global ISAACPRIV
global ISAACPREF

switch(choix)
case {'ButDown','ButSelect'}
	% L'image devient la cible
	obj = ISAACPRIV.TabIsaacImage([ISAACPRIV.TabIsaacImage.fighnd] == fighnd);
	IsaacImage_cible(obj,fighnd);
case 'CloseBox'
	if ~ISAACPRIV.IsEnd
		indice = find([ISAACPRIV.TabIsaacImage.fighnd] == fighnd);
		obj = ISAACPRIV.TabIsaacImage(indice);
		% suppression de l'image
		if (ISAACPRIV.NbOpenImg > 1)
			if (obj == ISAACPRIV.Cible) 
				% EVENEMENT
				IsaacImage_event(obj,fighnd,11)
			else
				% EVENEMENT
				IsaacImage_event(obj,fighnd,12)
			end
			% maj ISAACPRIV.TabIsaacImage
			ISAACPRIV.TabIsaacImage(indice) = [];
			ISAACPRIV.NbOpenImg = ISAACPRIV.NbOpenImg - 1;
			if (obj == ISAACPRIV.Cible) 
				% dsignation d'une nouvelle cible
				if (indice > ISAACPRIV.NbOpenImg)
					% l'image tait la dernire de la liste
					newcible = ISAACPRIV.TabIsaacImage(ISAACPRIV.NbOpenImg);
				else
					newcible = ISAACPRIV.TabIsaacImage(indice);
				end
				ISAACPRIV.Cible = newcible;
				% activation de la marque image de la nouvelle cible
				if (newcible.status == 1)
					set(findobj(newcible.fighnd,'Tag','ButSelect'),'BackgroundColor', ...
						ISAACPREF.CibleColor1)
				else
					set(findobj(newcible.fighnd,'Tag','ButSelect'),'BackgroundColor', ...
						ISAACPREF.CibleColor2)
				end
				% ractivation ventuelle du zoom
				if newcible.zoom
					zoom(newcible.fighnd,'on')
				end	
				% EVENEMENT
				IsaacImage_event(newcible,newcible.fighnd,2)
			end
		else
			% EVENEMENT
			IsaacImage_event(obj,fighnd,11) % l'image tait forcment la cible
			% maj ISAACPRIV.TabIsaacImage
			ISAACPRIV.TabIsaacImage(1) = [];
			ISAACPRIV.NbOpenImg = 0;
			% EVENEMENT
			IsaacImage_event(obj,fighnd,1)
		end
		% En rponse aux vnements mis, des figures ont pu se dclarer comme 'current'
		% et alors le closereq ci-dessous s'adresserait  elles !!!
		figure(fighnd)		
		closereq
	else	
		closereq
	end	
end
end