function IsaacImage_draw(obj)
% @IsaacImage (private) : affiche le contenu visuel de l'image en 3 plans C8 
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACCONST
global ISAACPREF

img = IsaacIMG_get(obj.img,'Img');
nbb = IsaacIMG_get(obj.img,'NbBits');
valmax = IsaacIMG_get(obj.img,'ValMax');
if obj.marginal
	if (nbb ~= 1)
		% affichage nivgris
		imgA = uint8(round(double(img(:,:,obj.plan(1)))*255/valmax));
		% ExpansionDynamique et Gamma
		if (obj.ED)
			mini = double(min(min(imgA)))/255;
			maxi = double(max(max(imgA)))/255;
			if mini ~= maxi
				imgA = imadjust(imgA,[mini,maxi],[],obj.gammaA);
			end
		elseif (obj.gammaA ~= 1)	
			imgA = imadjust(imgA,[],[],obj.gammaA);
		end
		% Palette de couleur et transformation en 3 plans C8 
		map = eval([char(ISAACCONST.PalStr(obj.pal)),'(256)']);
		imgA = reshape(im2uint8(map(double(imgA)+1,:)),size(imgA,1),size(imgA,2),3);
	else
		% affichage binaire
		imgA = repmat(uint8(img(:,:,obj.plan(1)))*255,[1,1,3]);
	end	
else
	% affichage couleur
	imgA = uint8(round(double(cat(3,img(:,:,obj.plan(1)),img(:,:,obj.plan(2)), ...
		img(:,:,obj.plan(3))))*255/valmax));
	if (nbb ~= 1)
		% ExpansionDynamique et Gamma (vectoriel)
		if (obj.ED)
			mini = double(min(min(min(imgA))))/255;
			maxi = double(max(max(max(imgA))))/255;
			if mini ~= maxi
				imgA = imadjust(imgA,[mini,maxi],[],obj.gammaA);
			end
		elseif (obj.gammaA ~= 1)	
			imgA = imadjust(imgA,[],[],obj.gammaA);
		end
	end	
end
% Dessin ROI
if IsaacIMG_get(obj.img,'IsRoi')
	switch obj.showRoiSpa
	case 0
		maskS = false(IsaacIMG_get(obj.img,'DimY'),IsaacIMG_get(obj.img,'DimX'));
	case 1
		maskS = IsaacIMG_get(obj.img,'RoiSpaMask');
	case 2
		maskS = ~IsaacIMG_get(obj.img,'RoiSpaMask');
	end
	switch obj.showRoiVal
	case 0
		maskV = false(IsaacIMG_get(obj.img,'DimY'),IsaacIMG_get(obj.img,'DimX'));
	case 1
		maskV = IsaacIMG_get(obj.img,'RoiValMask');
	case 2
		maskV = ~IsaacIMG_get(obj.img,'RoiValMask');
	end
	mask1 = maskS & ~maskV;
	mask2 = ~maskS & maskV;
	mask3 = maskS & maskV;
	if obj.showRoiComp
		mask4 = ~maskS & ~maskV;
	end	
	for k = 1:3
		p = imgA(:,:,k);
		p(mask1) = ISAACPREF.ROIColor1(k);
		p(mask2) = ISAACPREF.ROIColor2(k);
		p(mask3) = ISAACPREF.ROIColor3(k);
		if obj.showRoiComp
			p(mask4) = ISAACPREF.ROIColor4(k);
		end	
		imgA(:,:,k) = p;
	end
end
% Affichage
set(get(obj.axImg,'Children'),'CData',imgA)
end
