function obj = IsaacROI(varargin)
% @IsaacROI : constructeur
%
% (Appeler en TRY-CATCH pour sortie en erreur d'execution)
%
%	obj = IsaacROI(dimx,dimy,dimz,nbb)
%		=> objet @IsaacROI inactif par dfaut pour une image de rfrence
%
%	obj = IsaacROI(filename)
%		=> objet @IsaacROI lu dans un fichier
%
%	obj = IsaacROI()
%		=> objet @IsaacROI par dfaut
%			(non utilis mais obligatoire pour load si aucun objet cr prcdement)
%
%	- dimx,dimy,dimz,nbb : dimensions et nbbits image de rfrence
%	- filename				: nom du fichier dans rpertoire courant ou nom complet
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% IMAGE DE RFRENCE
%
%	ima_dimx	: dimension horizontale de l'image
%	ima_dimy	: dimension verticale de l'image
%	ima_dimz : nombre de plans de l'image
%	ima_nbb	: nombre de bits de l'image
%
% ROI SPATIALE
%
%	isspa		: true si roi spatiale active
%	spa_mat	: matrice(spa_nb,4) de [xmin,xmax,ymin,ymax] dans les limites de ima_dimx et ima_dimy
%	spa_nb	: nombre de lignes de spa_mat
%	spa_in	: true  : roi = interieur des intervalles bornes comprises
%				  false : roi = extrieur des intervalles bornes non comprises
%
% ROI VALEURS
%
%	isval		: matrice(1,ima_dimz) de true si roi valeurs plan p active pour 1 <= p <= ima_dimz
%  valmax   : 2^nbb -1 si ima_nbb <32 ou 1 si ima_nbb >=32
%	val_mat	: matrice(val_nb,ima_dimz*2,) de [v1min,v1max,...,vzmin,vzmax]
%				  avec 0 <= vp <= valmax et 1 <= p <= ima_dimz
%	val_nb	: nombre de lignes de val_mat
%	val_in	: true  : roi = interieur des intervalles bornes comprises
%				  false : roi = extrieur des intervalles bornes non comprises
%
%	NB : isspa et isval sont indpendants de spa_nb et val_nb
%
%  ATTENTION : spa_mat et val_mat codes en DOUBLE
%
%	version : version de l'objet 

%---------------------------------------------------------------------------------------------------

objversion = 1;

%---------------------------------------------------------------------------------------------------

global ISAACPREF

switch nargin
	case 4
		% Objet initialis par dfaut
		obj.ima_dimx = varargin{1};
		obj.ima_dimy = varargin{2};
		obj.ima_dimz = varargin{3};
		obj.ima_nbb  = varargin{4};
		if ((obj.ima_dimx < 2) || (obj.ima_dimy < 2) || (obj.ima_dimz > ISAACPREF.ImMaxPlans) || ...
			~ismember(obj.ima_nbb,[1:16,32,64]))
			error('argument incorrect')
		end	
		obj.isspa	= false;
		obj.spa_mat	= [];
		obj.spa_nb	= 0;
		obj.spa_in	= true;
		obj.isval	= false(1,obj.ima_dimz);
		if ismember(obj.ima_nbb,[1,32,64])
			obj.valmax = 1;
		else
			obj.valmax = 2^obj.ima_nbb - 1;
		end
		obj.val_mat	= [];
		obj.val_nb	= 0;
		obj.val_in	= true;
		obj.version = objversion;
		obj = class(orderfields(obj),'IsaacROI'); % orderfields car class est sensible  l'ordre
	case 1
		% Lecture dans un fichier
		try
			warning off
			var = load('-mat',varargin{1},'ROI'); % variable ROI dans le fichier
			warning on
			obj = var.ROI;
			if ~isa(obj,'IsaacROI')
				% erreur affiche par loadobj
				error('pour provoquer le catch')
			end
		catch
			error('fichier invalide')
		end
		if (obj.ima_dimz > ISAACPREF.ImMaxPlans)
			error('le nombre de plans dpasse la limite fixe en prfrences')
		end	
	case 0
		% Objet par dfaut non utilis mais obligatoire
		obj = struct('ima_dimx',{},'ima_dimy',{},'ima_dimz',{},'ima_nbb',{},'isspa',{}, ...
			'spa_mat',{},'spa_nb',{},'spa_in',{},'isval',{},'valmax',{},'val_mat',{},'val_nb',{}, ...
			'val_in',{},'version',{});
		obj = class(orderfields(obj),'IsaacROI'); % orderfields car class est sensible  l'ordre
	otherwise
		 error('nombre d''arguments incorrect')
end