function obj = IsaacROI_set(obj,varargin)
% @IsaacROI : criture d'une ou plusieurs proprits
%
%	obj = IsaacROI_set(obj,propname1,val1,...,propnameN,valN)
%
% propname		val
% --------		---
% 'IsRoiSpa'	obj.isspa
% 'IsRoiVal'	obj.isval
% 'RoiSpa'		obj.spa_mat ou []
% 'RoiSpaIn'	obj.spa_in
% 'RoiVal'		obj.val_mat ou []
% 'RoiValIn'	obj.val_in
%
%	ATTENTION : val de 'RoiSpa' et 'RoiVal' codes en DOUBLE
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

if (nargin < 3)
	error('nombre d''arguments incorrect')
end
propargin = varargin;
while (length(propargin) >= 2)
	propname = propargin{1};
	val = propargin{2};
	propargin = propargin(3:end);
	switch propname
		case 'IsRoiSpa'
			if ~islogical(val)
				error('argument incorrect')
			end	
			obj.isspa = val;
		case 'IsRoiVal'
			if ~islogical(val)
				error('argument incorrect')
			end	
			obj.isval = val;
		case 'RoiSpa'
			if isempty(val)
				obj.spa_nb = 0;
			else
				if (~isa(val,'double') || (size(val,2) ~= 4))
					error('argument incorrect')
				end
				n = size(val,1);
				for i = 1:n
					if ((val(i,1) < 1) || (val(i,2) > obj.ima_dimx) || (val(i,1) > val(i,2)) || ...
						 (val(i,3) < 1) || (val(i,4) > obj.ima_dimy) || (val(i,3) > val(i,4)))
						error('argument incorrect')
					end
				end
				obj.spa_nb = n;
			end
			obj.spa_mat = val;
		case 'RoiSpaIn'
			if ~islogical(val)
				error('argument incorrect')
			end	
			obj.spa_in = val;
		case 'RoiVal'
			if isempty(val)
				obj.val_nb = 0;
			else
				if (~isa(val,'double') || (size(val,2) ~= 2*obj.ima_dimz))
					error('argument incorrect')
				end
				n = size(val,1);
				for i = 1:n
					for j = 1:obj.ima_dimz
						if ((val(i,2*j-1) < 0) || (val(i,2*j-1) > val(i,2*j)) || ...
							(val(i,2*j) > obj.valmax))
							error('argument incorrect')
						end
					end	
				end
				obj.val_nb = n;
			end
			obj.val_mat = val;
		case 'RoiValIn'
			if ~islogical(val)
				error('argument incorrect')
			end	
			obj.val_in = val;
		otherwise
			error('argument incorrect')
	end
end
if ~isempty(propargin)
	error('nombre d''arguments incorrect')
end
