function varargout = Dispersion(varargin)
% Calcul la dispersion d'une image
% (racine carre de la trace de la matrice de variance-covariance)
% 
% INPUT:
% - image PxQ
%
% OUTPUT:
% - valeur numrique : dispersion
%
% Plugin for OpenIsaac
% version 1
%  2011-2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% PLUGIN PARAMETERS
if (nargin == 1) && strcmp(varargin{1},'-f')
    % input
	varargout{1} = {'IMG','image'};
    % output
	varargout{2} = {'DATA','dispersion'};
	return
end	

% INPUT
ObjIMG = varargin{1};

%---------------------------------------------------------------------------------------------------

[histo,counts] = IsaacModule('IsaacHistN',double(IsaacIMG_img2mat(ObjIMG)));
p = counts/sum(counts);
moy = p'*histo; % attention oprations matricielles : ordre impratif
var = p'*(histo.^2)-moy.^2;
disper = sqrt(sum(var));

%---------------------------------------------------------------------------------------------------

% OUTPUT
varargout{1} = IsaacDATA('VALN',disper,'dispersion');
