function ShowHisto(ud)
% Affichage de l'histogramme
%
% - ud : champ UserData de HistoEdit
%
% Tool for OpenIsaac
%  2018-2020 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2020 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACINFO

if ud.ShowGraph
	axes(ud.AxHisto) % ud.AxHisto = current
	cla reset % delete all et reset current axes sauf Units et Position
	set(ud.AxHisto,'Color',[1,1,1],'FontSize',ISAACINFO.FontSize - 1)
	historef = IsaacHISTO_get(ud.Param,'HistoRef');
	if historef.nb
		switch ud.AffDim
		case 1
            if verLessThan('matlab', '9.6')                
                % code pour MATLAB 2018b et antrieur
                if ud.BigDot
                    LW = 3;
                    MS = 3;
                else
                    LW = 1;
                    MS = 1;
                end    
            elseif verLessThan('matlab', '9.7') 
                % code pour MATLAB 2019a (9.6)
                if ud.BigDot
                    LW = 3;
                else    
                    LW = 1;
                end    
            else
                % code pour MATLAB 2019b (9.7) et postrieur
                if ud.BigDot
                    LW = 3;
                else    
                    LW = 1.01; % si LW=1 affiche des traits blancs rgulirement espacs
                end    
            end
			hold on
            if verLessThan('matlab', '9.6') 
                % code pour MATLAB 2018b et antrieur
                set(ud.AxHisto,'ColorOrder',[0.5 0.5 0.5])
                stem(IsaacHISTO_get(ud.Param,'Histo'),IsaacHISTO_get(ud.Param,'Counts'), ...
				'.','LineWidth',LW,'MarkerSize',MS)
            else
                % code pour MATLAB 2019a (9.6) et postrieur
                stem(IsaacHISTO_get(ud.Param,'Histo'),IsaacHISTO_get(ud.Param,'Counts'), ...
				'LineWidth',LW,'Marker','none','color',[0.5 0.5 0.5])
            end
			if (ud.AffRoi == 2)
				if ud.IsRoiMark
					historef = IsaacHISTO_get(ud.HistoROI,'HistoRef');
                    if verLessThan('matlab', '9.6') 
                        % code pour MATLAB 2018b et antrieur
                        set(ud.AxHisto,'ColorOrder',im2double(ISAACINFO.ROIColor3))
                        stem(IsaacHISTO_get(ud.HistoROI,'Histo'),repmat(ud.VisMax,historef.nb,1), ...
						'.','LineWidth',LW,'MarkerSize',MS)
                    else
                        % code pour MATLAB 2019a (9.6) et postrieur
                        stem(IsaacHISTO_get(ud.HistoROI,'Histo'),repmat(ud.VisMax,historef.nb,1), ...
						'LineWidth',LW,'Marker','none','color',ISAACINFO.ROIColor3)
                    end
                else
                    if verLessThan('matlab', '9.6') 
                        % code pour MATLAB 2018b et antrieur
                        set(ud.AxHisto,'ColorOrder',im2double(ISAACINFO.ROIColor3))
                        stem(IsaacHISTO_get(ud.HistoROI,'Histo'),IsaacHISTO_get(ud.HistoROI,'Counts'), ...
						'.','LineWidth',LW,'MarkerSize',MS)
                    else
                        % code pour MATLAB 2019a (9.6) et postrieur
                        stem(IsaacHISTO_get(ud.HistoROI,'Histo'),IsaacHISTO_get(ud.HistoROI,'Counts'), ...
						'LineWidth',LW,'Marker','none','color',ISAACINFO.ROIColor3)
                    end
				end
			end	
			hold off
			% Axes (rinitialiss par plot sauf Units et Position)
			set(ud.AxHisto,'Xlabel',text('String',['Plan',num2str(ud.AffPlans(1))]), ...
				'Xtick',ud.AxTick1,'Xgrid','on')
			axis([ud.AxXmin ud.AxXmax ud.VisMin 1.05*ud.VisMax]) % 5% de plus que la + gde valeur
		case 2
            if verLessThan('matlab', '9.6')                
                % code pour MATLAB 2018b et antrieur
                if ud.BigDot
                    LW = 3;
                else
                    LW = 1;
                end
                MS = 1;
            elseif verLessThan('matlab', '9.7') 
                % code pour MATLAB 2019a (9.6)
                if ud.BigDot
                    LW = 3;
                    MS = 12;
                else    
                    LW = 1;
                    MS = 1;
                end    
            else
                % code pour MATLAB 2019b (9.7) et postrieur
                if ud.BigDot
                    LW = 3;
                    MS = 12;
                else    
                    LW = 1.01; % si LW=1 affiche des traits blancs rgulirement espacs
                    MS = 1;
                end    
            end
			colormap(ud.TabColor) % pour barre de couleurs
			histo = IsaacHISTO_get(ud.Param,'Histo');
			counts = IsaacHISTO_get(ud.Param,'Counts');
			hold on
            for i = 1:ud.NbColor
				mask = roicolor(counts,ud.TabSeuil(i),ud.TabSeuil(i+1)-1);
                if verLessThan('matlab', '9.6') 
                	% code pour MATLAB 2018b et antrieur
                    set(ud.AxHisto,'ColorOrder',ud.TabColor(i,:))
					stem3(histo(mask,1),histo(mask,2),counts(mask),'LineWidth',LW,'MarkerSize',MS)
                else
                    % code pour MATLAB 2019a (9.6) et postrieur
                    % quand lvation = 90 la vue 3D (view) n'affiche rien si Marker = 'none'
                    % rappel de ShowHisto par HistoEdit_cb
                    if (ud.EL == 90)
                        stem3(histo(mask,1),histo(mask,2),counts(mask),'LineWidth',LW, ...
                        'Marker','.','MarkerSize',MS,'color',ud.TabColor(i,:))
                    else
                        stem3(histo(mask,1),histo(mask,2),counts(mask),'LineWidth',LW, ...
                        'Marker','none','color',ud.TabColor(i,:))
                    end
                end
			end
			if (ud.AffRoi == 2)
				roihisto = IsaacHISTO_get(ud.HistoROI,'Histo');
				if ud.IsRoiMark
					historef = IsaacHISTO_get(ud.HistoROI,'HistoRef');
                    if verLessThan('matlab', '9.6') 
                        % code pour MATLAB 2018b et antrieur
                        set(ud.AxHisto,'ColorOrder',im2double(ISAACINFO.ROIColor3))
                        stem3(roihisto(:,1),roihisto(:,2),repmat(ud.VisMax,historef.nb,1), ...
                        'LineWidth',LW,'MarkerSize',MS)
                    else
                        % code pour MATLAB 2019a (9.6) et postrieur
                        % quand lvation = 90 la vue 3D (view) n'affiche rien si Marker = 'none'
                        % rappel de ShowHisto par HistoEdit_cb
                        if (ud.EL == 90)
                            stem3(roihisto(:,1),roihisto(:,2), repmat(ud.VisMax,historef.nb,1), ...
                            'LineWidth',LW,'Marker','.','MarkerSize',MS,'color',ISAACINFO.ROIColor3)
                        else
                            stem3(roihisto(:,1),roihisto(:,2), repmat(ud.VisMax,historef.nb,1), ...
                            'LineWidth',LW,'Marker','none','color',ISAACINFO.ROIColor3)
                        end
                    end
                else
                    if verLessThan('matlab', '9.6') 
                        % code pour MATLAB 2018b et antrieur
                        set(ud.AxHisto,'ColorOrder',im2double(ISAACINFO.ROIColor3))
                        stem3(roihisto(:,1),roihisto(:,2),IsaacHISTO_get(ud.HistoROI,'Counts'), ...
                        'LineWidth',LW,'MarkerSize',MS)
                    else
                        % code pour MATLAB 2019a (9.6) et postrieur
                        % quand lvation = 90 la vue 3D (view) n'affiche rien si Marker = 'none'
                        % rappel de ShowHisto par HistoEdit_cb
                        if (ud.EL == 90)
                            stem3(roihisto(:,1),roihisto(:,2),IsaacHISTO_get(ud.HistoROI,'Counts'), ...
                            'LineWidth',LW,'Marker','.','MarkerSize',MS,'color',ISAACINFO.ROIColor3)
                        else
                            stem3(roihisto(:,1),roihisto(:,2),IsaacHISTO_get(ud.HistoROI,'Counts'), ...
                            'LineWidth',LW,'Marker','none','color',ISAACINFO.ROIColor3)
                        end
                    end
				end
			end	
			hold off
			% Axes (rinitialiss par plot sauf Units et Position)
			set(ud.AxHisto,'Xlabel',text('String',['Plan',num2str(ud.AffPlans(1))]), ...
				'Ylabel',text('String',['Plan',num2str(ud.AffPlans(2))]), ...
				'Xtick',ud.AxTick2,'Ytick',ud.AxTick2,'Xgrid','on','Ygrid','on','Zgrid','on')
			axis([ud.AxXmin ud.AxXmax ud.AxXmin ud.AxXmax ud.VisMin 1.05*ud.VisMax]) 
			% 5% de plus que la + gde valeur
			view([ud.AZ,ud.EL])
			% Remove 'o's from stem plot
			% delete(findobj(get(gca,'children'),'flat','Marker','o'))
		case 3
			if ud.BigDot
				MS = 12;
			else
				MS = 1;
			end
			colormap(ud.TabColor) % pour barre de couleurs
			histo = IsaacHISTO_get(ud.Param,'Histo');
            hold on
			for i = 1:(ud.NbColor)
				mask = roicolor(IsaacHISTO_get(ud.Param,'Counts'),ud.TabSeuil(i),ud.TabSeuil(i+1)-1);
				if verLessThan('matlab', '9.6') 
                    % code pour MATLAB 2018b et antrieur
                    set(ud.AxHisto,'ColorOrder',ud.TabColor(i,:))
                    plot3(histo(mask,1),histo(mask,2),histo(mask,3),'.','MarkerSize',MS)
                else
                     % code pour MATLAB 2019a (9.6) et postrieur
                    plot3(histo(mask,1),histo(mask,2),histo(mask,3),'.','MarkerSize',MS, ...
                    'color',ud.TabColor(i,:))
                end
			end
			if (ud.AffRoi == 2)
				roihisto = IsaacHISTO_get(ud.HistoROI,'Histo');
				mask = roicolor(IsaacHISTO_get(ud.HistoROI,'Counts'), ...
					ud.TabSeuil(1),ud.TabSeuil(ud.NbColor+1)-1);
				if verLessThan('matlab', '9.6') 
                    % code pour MATLAB 2018b et antrieur
                    set(ud.AxHisto,'ColorOrder',im2double(ISAACINFO.ROIColor3))
                    plot3(roihisto(mask,1),roihisto(mask,2),roihisto(mask,3),'.','MarkerSize',MS)
                else
                     % code pour MATLAB 2019a (9.6) et postrieur
                    plot3(roihisto(mask,1),roihisto(mask,2),roihisto(mask,3),'.','MarkerSize',MS, ...
                    'color',ISAACINFO.ROIColor3)
                end
			end	
			hold off
			% Axes (rinitialiss par plot sauf Units et Position)
			set(ud.AxHisto,'Xlabel',text('String',['Plan',num2str(ud.AffPlans(1))]), ...
				'Ylabel',text('String',['Plan',num2str(ud.AffPlans(2))]), ...
				'Zlabel',text('String',['Plan',num2str(ud.AffPlans(3))]), ...
				'Xtick',ud.AxTick2,'Ytick',ud.AxTick2,'Ztick',ud.AxTick2, ...
				'Xgrid','on','Ygrid','on','Zgrid','on')
			axis([ud.AxXmin ud.AxXmax ud.AxXmin ud.AxXmax ud.AxXmin ud.AxXmax])
			view([ud.AZ,ud.EL])
		end
	end	
else
	iref = IsaacHISTO_get(ud.Param,'ImaRef');
	href = IsaacHISTO_get(ud.Param,'HistoRef');
	cref = IsaacHISTO_get(ud.Param,'CountsRef');
	if iref.useroi
		isroistr = 'oui';
	else
		isroistr = 'non';
	end
	s = {'';'';'';''; ...
		[' histogramme : [',num2str([href.nb,href.dim]),']']; ...
		[' nb bits     : ',num2str(href.bitclass)]; ...
		[' min         : [',num2str(href.min,ud.FormatStr),']']; ...
		[' max         : [',num2str(href.max,ud.FormatStr),']']; ...
		''; ...
		[' effectif    : ',num2str(cref.effsum)]; ...
		[' min         : ',num2str(cref.effmin)]; ...
		[' max         : ',num2str(cref.effmax)]; ...
		''; ...
		[' image       : ',iref.name]; ...
		[' nb bits     : ',num2str(iref.nbb)]; ...
		[' nb plans    : ',num2str(iref.dimz)]; ...
		[' nb pixels   : ',num2str(iref.nbpix)]; ...
		[' plans       : [',num2str(href.plans),']']; ...
		[' histo roi   : ',isroistr]};
	set(ud.HistoInfoHnd,'String',s)
end	