function RoiEdit()
% Editeur de @IsaacROI
%
% Tool for OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% structure ud : champ UserData
%	ToolDir			: rpertoire de l'outil
%	PTarget			: 1 = image cible, 2 = mmoire, 3 = fichier, 4  = MATLAB base workspace
%	PVarName       : nom de la variable associe au paramtre dit
%	Param          : objet @IsaacROI
%	RoiSpaL			: ligne slectionne dans RoiSpa
%	RoiSpaE1       : entre RoiSpa xmin
%	RoiSpaE2       : entre RoiSpa xmax
%	RoiSpaE3       : entre RoiSpa ymin
%	RoiSpaE4       : entre RoiSpa ymmax
%	RoiSpaFormat	: format d'affichage des valeurs de RoiSpa
%	RoiValL			: ligne slectionne dans RoiVal
%	RoiValP			: plan slectionn dans RoiVal
%	RoiValE1       : entre RoiVal vmin
%	RoiValE2       : entre RoiVal vmax
%	RoiValFormat	: format d'affichage des valeurs de RoiVal

%---------------------------------------------------------------------------------------------------

global ISAACINFO

% si RoiEdit est dja lanc, l'ammener au premier plan.
h = findobj(allchild(0),'flat','Tag','RoiEdit');
if ~isempty(h)
	figure(h(1)) % mise au 1er plan
   return
end

hauteurfig = 470;
% figure(position selon ISAACINFO.DefPos)
h0 = figure( ...
	'CloseRequestFcn','RoiEdit_cb CloseBox', ...
	'Name','RoiEdit', ...
	'Position',IsaacFenPos(ISAACINFO.DefPos(1),ISAACINFO.DefPos(2),290,hauteurfig,0), ...
	'Tag','RoiEdit');

IsaacDefaultProperties(h0)

% text ParamInfo -----------------------------------------------------------------------------------	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[0 hauteurfig - 15 290 15], ...
	'Style','text', ...
	'Tag','StxtParamInfo');
% checkbox ROI spatiale	----------------------------------------------------------------------------
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb ChkRoiSpatiale', ...
	'Enable','off', ...
	'FontAngle','italic', ...
	'String','ROI Spatiale', ...
	'Style','checkbox', ...
	'Position',[15 hauteurfig - 36 90 18], ...
	'Tag','ChkRoiSpatiale');
% Boutons radio RS "OU/NI"
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb RadButRSOU', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize - 1, ...
	'String','OU', ...
	'Style','radiobutton', ...
	'Position',[110 hauteurfig - 35 40 15], ...
	'Tag','RadButRSOU');
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb RadButRSNI', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize - 1, ...
	'String','NI', ...
	'Style','radiobutton', ...
	'Position',[150 hauteurfig - 35 40 15], ...
	'Tag','RadButRSNI');
% liste RS
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','RoiEdit_cb ListRS', ...
	'Enable','off', ...
	'FontName','Monospaced', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'SelectionHighlight','off', ...
	'Position',[5 hauteurfig - 115 200 75], ...
	'Style','listbox', ...
	'Tag','ListRS');
% text legende RS	
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 135 210 15], ...
	'String','    Xmin       Xmax       Ymin      Ymax', ...
	'Style','text');	
% edit RS1	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','RoiEdit_cb EtxtRS1', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[10 hauteurfig - 160 40 22], ...
	'Style','edit', ...
	'Tag','EtxtRS1');
% edit RS2	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','RoiEdit_cb EtxtRS2', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[55 hauteurfig - 160 40 22], ...
	'Style','edit', ...
	'Tag','EtxtRS2');
% edit RS3	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','RoiEdit_cb EtxtRS3', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[100 hauteurfig - 160 40 22], ...
	'Style','edit', ...
	'Tag','EtxtRS3');
% edit RS4	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','RoiEdit_cb EtxtRS4', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[145 hauteurfig - 160 40 22], ...
	'Style','edit', ...
	'Tag','EtxtRS4');
% text RS effectif
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[215 hauteurfig - 48 70 15], ...
	'String',' Effectif', ...
	'Style','text');
% text RS effectif val
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[215 hauteurfig - 65 70 15], ...
	'Style','text', ...
	'Tag','StxtRSeffval');
% bouton RSselect
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButRSselect', ...
	'Enable','off', ...
	'Position',[215 hauteurfig - 90 70 20], ...
	'String','Selection', ...
	'Tag','ButRSselect');
% bouton RSlp
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButRSlp', ...
	'Enable','off', ...
	'Position',[215 hauteurfig - 112 70 20], ...
	'String','LPIX', ...
	'Tag','ButRSlp');
% bouton RSclear
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButRSclear', ...
	'Enable','off', ...
	'Position',[215 hauteurfig - 134 70 20], ...
	'String','Effacer', ...
	'Tag','ButRSclear');
% bouton RS+
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButRS+', ...
	'Enable','off', ...
	'Position',[232 hauteurfig - 160 16 16], ...
	'String','+', ...
	'Tag','ButRS+');
% bouton RS-
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButRS-', ...
	'Enable','off', ...
	'Position',[254 hauteurfig - 160 16 16], ...
	'String','-', ...
	'Tag','ButRS-');
% Sparateur ---------------------------------------------------------------------------------------
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 170 290 1], ...
	'Style','frame');
% text ROI valeurs	
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'FontAngle','italic', ...
	'Position',[10 hauteurfig - 190 70 15], ...
	'String','ROI Valeurs', ...
	'Style','text');
% Boutons radio RV "OU/NI"
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb RadButRVOU', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize - 1, ...
	'String','OU', ...
	'Style','radiobutton', ...
	'Position',[105 hauteurfig - 190 40 15], ...
	'Tag','RadButRVOU');
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb RadButRVNI', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize - 1, ...
	'String','NI', ...
	'Style','radiobutton', ...
	'Position',[145 hauteurfig - 190 40 15], ...
	'Tag','RadButRVNI');
% liste RV
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','RoiEdit_cb ListRV', ...
	'Enable','off', ...
	'FontName','Monospaced', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'SelectionHighlight','off', ...
	'Position',[5 hauteurfig - 270 200 75], ...
	'Style','listbox', ...
	'Tag','ListRV');
% text legende RV	
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 290 210 15], ...
	'String','      Plan                       Min           Max', ...
	'Style','text');
% popup plans RV
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb PopupPlanRV', ...
	'Enable','off', ...
	'Position',[5 hauteurfig - 310 65 16], ...
	'String',' ', ...
	'Style','popupmenu', ...
	'Tag','PopupPlanRV');
% checkbox ChkRoiValeurs	
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb ChkRoiValeurs', ...
	'Enable','off', ...
	'Style','checkbox', ...
	'Position',[70 hauteurfig - 314 18 18], ...
	'Tag','ChkRoiValeurs');
% edit RV1	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','RoiEdit_cb EtxtRV1', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[95 hauteurfig - 315 50 22], ...
	'Style','edit', ...
	'Tag','EtxtRV1');
% edit RV2	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','RoiEdit_cb EtxtRV2', ...
	'Enable','off', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[150 hauteurfig - 315 50 22], ...
	'Style','edit', ...
	'Tag','EtxtRV2');
% text RV effectif
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[215 hauteurfig - 203 70 15], ...
	'String',' Effectif', ...
	'Style','text');
% text RV effectif val	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[215 hauteurfig - 220 70 15], ...
	'Style','text', ...
	'Tag','StxtRVeffval');	
% bouton RVlp
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButRVlp', ...
	'Enable','off', ...
	'Position',[215 hauteurfig - 268 70 20], ...
	'String','LPIX', ...
	'Tag','ButRVlp');
% bouton RVclear
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButRVclear', ...
	'Enable','off', ...
	'Position',[215 hauteurfig - 289 70 20], ...
	'String','Effacer', ...
	'Tag','ButRVclear');
% bouton RV+
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButRV+', ...
	'Enable','off', ...
	'Position',[232 hauteurfig - 315 16 16], ...
	'String','+', ...
	'Tag','ButRV+');
% bouton RV-
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButRV-', ...
	'Enable','off', ...
	'Position',[254 hauteurfig - 315 16 16], ...
	'String','-', ...
	'Tag','ButRV-');
% bouton DoMasqueS
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButDoMasqueS', ...
	'Position',[5 hauteurfig - 345 90 20], ...
	'String','Masque S', ...
	'Tag','ButDoMasqueS');
% bouton DoMasqueV
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButDoMasqueV', ...
	'Position',[100 hauteurfig - 345 90 20], ...
	'String','Masque V', ...
	'Tag','ButDoMasqueV');
% bouton DoMasqueSV
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButDoMasqueSV', ...
	'Position',[195 hauteurfig - 345 90 20], ...
	'String','Masque SV', ...
	'Tag','ButDoMasqueSV');
% Sparateur ---------------------------------------------------------------------------------------
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 355 290 1], ...
	'Style','frame');
% text TargetInfo	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[5 hauteurfig - 375 280 15], ...
	'Style','text', ...
	'Tag','StxtTargetInfo');
% Bouton radio Param image cible
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb RadButParamCible', ...
	'String','Image cible', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 400 190 15], ...
	'Tag','RadButParamCible', ...
	'Value',1);
% Bouton radio Param mmoire
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb RadButParamMem', ...
	'String','Mmoire', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 420 100 15], ...
	'Tag','RadButParamMem', ...
	'Value',0);
% Bouton radio Param fichier
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb RadButParamFich', ...
	'String','Fichier', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 440 100 15], ...
	'Tag','RadButParamFich', ...
	'Value',0);
% Bouton radio Param MATLAB
uicontrol('Parent',h0, ...
	'Callback','RoiEdit_cb RadButParamMATLAB', ...
	'String','MATLAB', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 460 100 15], ...
	'Tag','RadButParamMATLAB');
% edit Varname	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','RoiEdit_cb EtxtVarname', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[90 hauteurfig - 463 80 22], ...
	'Style','edit', ...
	'Tag','EtxtVarname');
% bouton ParamPull
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButParamPull', ...
	'Position',[195 hauteurfig - 410 90 20], ...
	'String','Crer', ...
	'Tag','ButParamPull');
% bouton ParamPush
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButParamPush', ...
	'Position',[195 hauteurfig - 435 90 20], ...
	'String','Appliquer', ...
	'Tag','ButParamPush');
% bouton Supprimer
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','RoiEdit_cb ButSupprimer', ...
	'Position',[195 hauteurfig - 460 90 20], ...
	'String','Supprimer', ...
	'Tag','ButSupprimer');
%---------------------------------------------------------------------------------------------------

% Initialisation

ud.ToolDir = fileparts(mfilename('fullpath'));
ud.PTarget = 1; % image cible
ud.Param = [];
ud.PVarName = 'x';
set(findobj(h0,'Tag','EtxtVarname'),'String',ud.PVarName,'Visible','off')
set(h0,'UserData',ud);
addpath(ud.ToolDir)
IsaacEventUpdListe(h0,ud.ToolDir,'RoiEdit_upd') % abonnement aux vnements
cible = IsaacImageCible;
if isempty(cible)
	RoiEdit_upd(h0,1,cible,NaN)
else
	RoiEdit_upd(h0,2,cible,NaN)
end
% auteur = NaN car n'accepte pas les vnements causs par soi-mme pour mise  jour graphique