function IsaacNewImage()
% Cration nouvelle image (dialogue modal)
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% structure ud : champ UserData
%	Nbb	: 1/8/16/32/64 bits par pixel et par plan
%	DimX	: nombre de colonnes >= 2
%	DimY	: nombre de lignes >= 2
%	DimZ	: 1 <= nombre de plans <= ISAACPREF.ImMaxPlans
%	Val	: valeur image =  matrice 1xDimZ

%---------------------------------------------------------------------------------------------------

global ISAACPREF
global ISAACCONST

try
	% Lecture des prfrences
	if exist(fullfile(ISAACCONST.PrefDir,'NewImagePrefs.mat'),'file')
		var = load(fullfile(ISAACCONST.PrefDir,'NewImagePrefs.mat'), 'ud');
		ud = var.ud;
		if ud.DimZ > ISAACPREF.ImMaxPlans
			ud.DimZ = ISAACPREF.ImMaxPlans;
		end	
	else
		% Prfrences par dfaut
		ud.Nbb = 8;
		ud.DimX = 256;
		ud.DimY = 256;
		ud.DimZ = 1;
		ud.Val = 0;
		% Sauvegarde prfrences par dfaut
		save(fullfile(ISAACCONST.PrefDir,'NewImagePrefs.mat'),'ud')
	end
catch exception
	IsaacMessageErreur(IsaacError(exception))
	return
end	

% figure(position selon ISAACCONST.DefPos)
h0 = figure( ...
	'CloseRequestFcn','IsaacNewImage_cb ButCancel', ...
	'Name','Nouvelle image', ...
	'Position',IsaacFenPos(ISAACCONST.DefPos(1),ISAACCONST.DefPos(2),245,140,0), ...
	'WindowStyle','modal');

IsaacDefaultProperties(h0)

% text Nbbits
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACPREF.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 115 40 15], ...
	'String','Nb bits :', ...
	'Style','text');
% radiobouton 1
uicontrol('Parent',h0, ...
	'Callback','IsaacNewImage_cb Rad1', ...
	'Position',[50 116 35 15], ...
	'String','1', ...
	'Style','radiobutton', ...
	'Tag','Rad1');
% radiobouton 8
uicontrol('Parent',h0, ...
	'Callback','IsaacNewImage_cb Rad8', ...
	'Position',[85 116 35 15], ...
	'String','8', ...
	'Style','radiobutton', ...
	'Tag','Rad8');
% radiobouton 16
uicontrol('Parent',h0, ...
	'Callback','IsaacNewImage_cb Rad16', ...
	'Position',[120 116 40 15], ...
	'String','16', ...
	'Style','radiobutton', ...
	'Tag','Rad16');
% radiobouton 32
uicontrol('Parent',h0, ...
	'Callback','IsaacNewImage_cb Rad32', ...
	'Position',[160 116 40 15], ...
	'String','32', ...
	'Style','radiobutton', ...
	'Tag','Rad32');
% radiobouton 64
uicontrol('Parent',h0, ...
	'Callback','IsaacNewImage_cb Rad64', ...
	'Position',[200 116 40 15], ...
	'String','64', ...
	'Style','radiobutton', ...
	'Tag','Rad64');
% text Dimensions
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACPREF.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 85 100 15], ...
	'String','Dimensions (X,Y,Z) :', ...
	'Style','text');
% edit DimX	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacNewImage_cb EtxtDimX', ...
	'FontSize',ISAACPREF.FontSize, ...
	'Position',[110 80 40 22], ...
	'String',num2str(ud.DimX), ...
	'Style','edit');
% edit DimY	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacNewImage_cb EtxtDimY', ...
	'FontSize',ISAACPREF.FontSize, ...
	'Position',[155 80 40 22], ...
	'String',num2str(ud.DimY), ...
	'Style','edit');
% edit DimZ	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacNewImage_cb EtxtDimZ', ...
	'FontSize',ISAACPREF.FontSize, ...
	'Position',[200 80 40 22], ...
	'String',num2str(ud.DimZ), ...
	'Style','edit');
% text Val
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACPREF.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 51 120 15], ...
	'Style','text', ...
	'Tag','StxtVal');
% popup Plan
s = cell(ud.DimZ,1);
for i = 1:ud.DimZ
	s{i} = num2str(i);
end
uicontrol('Parent',h0, ...
	'Callback','IsaacNewImage_cb PopupPlan', ...
	'Position',[95 52 65 16], ...
	'String',s,	...
	'Style','popupmenu', ...
	'Value',1, ...
	'Tag','PopupPlan');
% edit Val	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacNewImage_cb EtxtVal', ...
	'FontSize',ISAACPREF.FontSize, ...
	'Position',[165 49 75 22], ...
	'Style','edit', ...
	'Tag','EtxtVal');
% Bouton Cancel
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor3, ...
	'Callback','IsaacNewImage_cb ButCancel', ...
	'Position',[115 5 60 20], ...
	'String','Annuler');
% Bouton OK	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor3, ...
	'Callback','IsaacNewImage_cb ButOk', ...
	'Position',[180 5 60 20], ...
	'String','Valider');

%---------------------------------------------------------------------------------------------------

% Initialisation

switch ud.Nbb
	case 1
		set(findobj(h0,'Tag','Rad1'),'Value',1)
		set(findobj(h0,'Tag','Rad8'),'Value',0)
		set(findobj(h0,'Tag','Rad16'),'Value',0)
		set(findobj(h0,'Tag','Rad32'),'Value',0)
		set(findobj(h0,'Tag','Rad64'),'Value',0)
	case 8
		set(findobj(h0,'Tag','Rad1'),'Value',0)
		set(findobj(h0,'Tag','Rad8'),'Value',1)
		set(findobj(h0,'Tag','Rad16'),'Value',0)
		set(findobj(h0,'Tag','Rad32'),'Value',0)
		set(findobj(h0,'Tag','Rad64'),'Value',0)
	case 16
		set(findobj(h0,'Tag','Rad1'),'Value',0)
		set(findobj(h0,'Tag','Rad8'),'Value',0)
		set(findobj(h0,'Tag','Rad16'),'Value',1)
		set(findobj(h0,'Tag','Rad32'),'Value',0)
		set(findobj(h0,'Tag','Rad64'),'Value',0)
	case 32
		set(findobj(h0,'Tag','Rad1'),'Value',0)
		set(findobj(h0,'Tag','Rad8'),'Value',0)
		set(findobj(h0,'Tag','Rad16'),'Value',0)
		set(findobj(h0,'Tag','Rad32'),'Value',1)
		set(findobj(h0,'Tag','Rad64'),'Value',0)
	case 64
		set(findobj(h0,'Tag','Rad1'),'Value',0)
		set(findobj(h0,'Tag','Rad8'),'Value',0)
		set(findobj(h0,'Tag','Rad16'),'Value',0)
		set(findobj(h0,'Tag','Rad32'),'Value',0)
		set(findobj(h0,'Tag','Rad64'),'Value',1)
end
ud = IsaacNewImage_maj(h0,ud,'NbBits');
set(h0,'UserData',ud)
if ud.DimZ == 1
	set(findobj(h0,'Tag','PopupPlan'),'Enable','off')
else
	set(findobj(h0,'Tag','PopupPlan'),'Enable','on')
end

uiwait(h0) % bloque l'execution de l'appelant jusqu' resume ou close figure

